@@ -79,6 +79,7 @@ class RussianProfileUpdateContract(ProfileUpdateContract):
     passport_number = serializers.CharField(max_length=6)
     passport_code = serializers.CharField(max_length=16)
     passport_date = serializers.DateField()
+    document = serializers.CharField(max_length=512, allow_null=True, allow_blank=True)
 
 
 class RussianProfileCreateContract(ProfileCreateContract):
@@ -88,6 +89,8 @@ class RussianProfileCreateContract(ProfileCreateContract):
     passport_code = serializers.CharField(max_length=16)
     passport_date = serializers.DateField()
     income = serializers.IntegerField(allow_null=True, required=False)
+    snils = serializers.CharField(max_length=64, allow_null=True, allow_blank=True)
+    document = serializers.CharField(max_length=512, allow_null=True, allow_blank=True)
 
 
 class RussianProfileReadContract(ProfileReadContract, ):
@@ -100,6 +103,7 @@ class RussianProfileReadContract(ProfileReadContract, ):
     income_region = serializers.IntegerField(allow_null=True)
     court_address = serializers.CharField(max_length=256, allow_blank=True)
     fias_region = serializers.CharField(max_length=256, allow_blank=True)
+    snils = serializers.CharField(max_length=64, allow_null=True, allow_blank=True)
 
 
 class UserProfileIpExistsCreateContract(Contract):
